==> estateplat-common-1.1.0-20160726.011606-129-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡权利人
 */
@Table(name = "GD_LS_QLR")
public class GdLsQlr implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String qlrid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人名称
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人身份证件种类
     */
    private String qlrsfzjzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利ID
     */
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人类型
     */
    private String qlrlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人性质
     */
    private String qlrxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 共有比例
     */
    private String qlbl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目id
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 是否持证人
     */
    private String sfczr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 产权证号
     */
    private String cqzh;

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }


}

==> estateplat-common-1.2.4-20200706.014042-382-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡权利人
 */
@Table(name = "GD_LS_QLR")
public class GdLsQlr implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String qlrid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人名称
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人身份证件种类
     */
    private String qlrsfzjzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人证件发证机关
     */
    private String qlrzjfzjg;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 国家
     */
    private String gj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 所属行业
     */
    private String sshy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 户籍所在省市
     */
    private String hjszss;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 性别
     */
    private String xb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 电话
     */
    private String dh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 地址
     */
    private String dz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 邮编
     */
    private String yb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 工作单位
     */
    private String gzdw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 电子邮件
     */
    private String dzyj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利ID
     */
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人类型
     */
    private String qlrlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利人性质
     */
    private String qlrxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 共有比例
     */
    private String qlbl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 共有方式
     */
    private String gyfs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人顺序号
     */
    private int qlrsxh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目id
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 是否持证人
     */
    private String sfczr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 产权证号
     */
    private String cqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 备注
     */
    private String bz;

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }


    public String getQlrzjfzjg() {
        return qlrzjfzjg;
    }

    public void setQlrzjfzjg(String qlrzjfzjg) {
        this.qlrzjfzjg = qlrzjfzjg;
    }

    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public int getQlrsxh() {
        return qlrsxh;
    }

    public void setQlrsxh(int qlrsxh) {
        this.qlrsxh = qlrsxh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
